/****************************************************************************
** Meta object code from reading C++ file 'radselectview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.08.3/radselect/radselectview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'radselectview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RadSelectView_t {
    QByteArrayData data[20];
    char stringdata0[250];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RadSelectView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RadSelectView_t qt_meta_stringdata_RadSelectView = {
    {
QT_MOC_LITERAL(0, 0, 13), // "RadSelectView"
QT_MOC_LITERAL(1, 14, 21), // "signalChangeStatusbar"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 4), // "text"
QT_MOC_LITERAL(4, 42, 14), // "searchModified"
QT_MOC_LITERAL(5, 57, 13), // "kanjiSelected"
QT_MOC_LITERAL(6, 71, 9), // "kanjiList"
QT_MOC_LITERAL(7, 81, 12), // "loadSettings"
QT_MOC_LITERAL(8, 94, 18), // "strokeLimitChanged"
QT_MOC_LITERAL(9, 113, 8), // "newvalue"
QT_MOC_LITERAL(10, 122, 13), // "changedSearch"
QT_MOC_LITERAL(11, 136, 11), // "clearSearch"
QT_MOC_LITERAL(12, 148, 12), // "kanjiClicked"
QT_MOC_LITERAL(13, 161, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(14, 178, 4), // "item"
QT_MOC_LITERAL(15, 183, 18), // "kanjiDoubleClicked"
QT_MOC_LITERAL(16, 202, 17), // "listPossibleKanji"
QT_MOC_LITERAL(17, 220, 12), // "QList<Kanji>"
QT_MOC_LITERAL(18, 233, 4), // "list"
QT_MOC_LITERAL(19, 238, 11) // "toClipboard"

    },
    "RadSelectView\0signalChangeStatusbar\0"
    "\0text\0searchModified\0kanjiSelected\0"
    "kanjiList\0loadSettings\0strokeLimitChanged\0"
    "newvalue\0changedSearch\0clearSearch\0"
    "kanjiClicked\0QListWidgetItem*\0item\0"
    "kanjiDoubleClicked\0listPossibleKanji\0"
    "QList<Kanji>\0list\0toClipboard"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RadSelectView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    0,   72,    2, 0x06 /* Public */,
       5,    1,   73,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   76,    2, 0x08 /* Private */,
       8,    1,   77,    2, 0x08 /* Private */,
      10,    0,   80,    2, 0x08 /* Private */,
      11,    0,   81,    2, 0x08 /* Private */,
      12,    1,   82,    2, 0x08 /* Private */,
      15,    1,   85,    2, 0x08 /* Private */,
      16,    1,   88,    2, 0x08 /* Private */,
      19,    0,   91,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,

       0        // eod
};

void RadSelectView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RadSelectView *_t = static_cast<RadSelectView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalChangeStatusbar((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->searchModified(); break;
        case 2: _t->kanjiSelected((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 3: _t->loadSettings(); break;
        case 4: _t->strokeLimitChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->changedSearch(); break;
        case 6: _t->clearSearch(); break;
        case 7: _t->kanjiClicked((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 8: _t->kanjiDoubleClicked((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 9: _t->listPossibleKanji((*reinterpret_cast< const QList<Kanji>(*)>(_a[1]))); break;
        case 10: _t->toClipboard(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (RadSelectView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RadSelectView::signalChangeStatusbar)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (RadSelectView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RadSelectView::searchModified)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (RadSelectView::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RadSelectView::kanjiSelected)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject RadSelectView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_RadSelectView.data,
      qt_meta_data_RadSelectView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RadSelectView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RadSelectView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RadSelectView.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::radical_selector"))
        return static_cast< Ui::radical_selector*>(this);
    return QWidget::qt_metacast(_clname);
}

int RadSelectView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void RadSelectView::signalChangeStatusbar(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void RadSelectView::searchModified()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RadSelectView::kanjiSelected(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
