/****************************************************************************
** Meta object code from reading C++ file 'dictfilefieldselector.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.08.3/lib/DictEdict/dictfilefieldselector.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dictfilefieldselector.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DictFileFieldSelector_t {
    QByteArrayData data[13];
    char stringdata0[175];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DictFileFieldSelector_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DictFileFieldSelector_t qt_meta_stringdata_DictFileFieldSelector = {
    {
QT_MOC_LITERAL(0, 0, 21), // "DictFileFieldSelector"
QT_MOC_LITERAL(1, 22, 13), // "widgetChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 12), // "setAvailable"
QT_MOC_LITERAL(4, 50, 4), // "list"
QT_MOC_LITERAL(5, 55, 12), // "addAvailable"
QT_MOC_LITERAL(6, 68, 14), // "setDefaultList"
QT_MOC_LITERAL(7, 83, 13), // "readFromPrefs"
QT_MOC_LITERAL(8, 97, 12), // "writeToPrefs"
QT_MOC_LITERAL(9, 110, 13), // "updateWidgets"
QT_MOC_LITERAL(10, 124, 20), // "updateWidgetsDefault"
QT_MOC_LITERAL(11, 145, 14), // "updateSettings"
QT_MOC_LITERAL(12, 160, 14) // "settingChanged"

    },
    "DictFileFieldSelector\0widgetChanged\0"
    "\0setAvailable\0list\0addAvailable\0"
    "setDefaultList\0readFromPrefs\0writeToPrefs\0"
    "updateWidgets\0updateWidgetsDefault\0"
    "updateSettings\0settingChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DictFileFieldSelector[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   65,    2, 0x0a /* Public */,
       5,    1,   68,    2, 0x0a /* Public */,
       6,    1,   71,    2, 0x0a /* Public */,
       7,    0,   74,    2, 0x0a /* Public */,
       8,    0,   75,    2, 0x0a /* Public */,
       9,    0,   76,    2, 0x0a /* Public */,
      10,    0,   77,    2, 0x0a /* Public */,
      11,    0,   78,    2, 0x0a /* Public */,
      12,    0,   79,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QStringList,    4,
    QMetaType::Void, QMetaType::QStringList,    4,
    QMetaType::Void, QMetaType::QStringList,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DictFileFieldSelector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DictFileFieldSelector *_t = static_cast<DictFileFieldSelector *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->widgetChanged(); break;
        case 1: _t->setAvailable((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 2: _t->addAvailable((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 3: _t->setDefaultList((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 4: _t->readFromPrefs(); break;
        case 5: _t->writeToPrefs(); break;
        case 6: _t->updateWidgets(); break;
        case 7: _t->updateWidgetsDefault(); break;
        case 8: _t->updateSettings(); break;
        case 9: _t->settingChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (DictFileFieldSelector::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DictFileFieldSelector::widgetChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject DictFileFieldSelector::staticMetaObject = {
    { &DictionaryPreferenceDialog::staticMetaObject, qt_meta_stringdata_DictFileFieldSelector.data,
      qt_meta_data_DictFileFieldSelector,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DictFileFieldSelector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DictFileFieldSelector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DictFileFieldSelector.stringdata0))
        return static_cast<void*>(this);
    return DictionaryPreferenceDialog::qt_metacast(_clname);
}

int DictFileFieldSelector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DictionaryPreferenceDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void DictFileFieldSelector::widgetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
