/****************************************************************************
** Meta object code from reading C++ file 'buttongrid.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.08.3/radselect/buttongrid.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'buttongrid.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ButtonGrid_t {
    QByteArrayData data[15];
    char stringdata0[187];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ButtonGrid_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ButtonGrid_t qt_meta_stringdata_ButtonGrid = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ButtonGrid"
QT_MOC_LITERAL(1, 11, 21), // "signalChangeStatusbar"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 4), // "text"
QT_MOC_LITERAL(4, 39, 13), // "possibleKanji"
QT_MOC_LITERAL(5, 53, 12), // "QList<Kanji>"
QT_MOC_LITERAL(6, 66, 9), // "kanjiList"
QT_MOC_LITERAL(7, 76, 21), // "clearButtonSelections"
QT_MOC_LITERAL(8, 98, 14), // "radicalClicked"
QT_MOC_LITERAL(9, 113, 6), // "newrad"
QT_MOC_LITERAL(10, 120, 27), // "RadicalButton::ButtonStatus"
QT_MOC_LITERAL(11, 148, 9), // "newStatus"
QT_MOC_LITERAL(12, 158, 15), // "clearSelections"
QT_MOC_LITERAL(13, 174, 7), // "setFont"
QT_MOC_LITERAL(14, 182, 4) // "font"

    },
    "ButtonGrid\0signalChangeStatusbar\0\0"
    "text\0possibleKanji\0QList<Kanji>\0"
    "kanjiList\0clearButtonSelections\0"
    "radicalClicked\0newrad\0RadicalButton::ButtonStatus\0"
    "newStatus\0clearSelections\0setFont\0"
    "font"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ButtonGrid[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    1,   47,    2, 0x06 /* Public */,
       7,    0,   50,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    2,   51,    2, 0x0a /* Public */,
      12,    0,   56,    2, 0x0a /* Public */,
      13,    1,   57,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 10,    9,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QFont,   14,

       0        // eod
};

void ButtonGrid::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ButtonGrid *_t = static_cast<ButtonGrid *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalChangeStatusbar((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->possibleKanji((*reinterpret_cast< const QList<Kanji>(*)>(_a[1]))); break;
        case 2: _t->clearButtonSelections(); break;
        case 3: _t->radicalClicked((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< RadicalButton::ButtonStatus(*)>(_a[2]))); break;
        case 4: _t->clearSelections(); break;
        case 5: _t->setFont((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ButtonGrid::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ButtonGrid::signalChangeStatusbar)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ButtonGrid::*_t)(const QList<Kanji> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ButtonGrid::possibleKanji)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ButtonGrid::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ButtonGrid::clearButtonSelections)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject ButtonGrid::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ButtonGrid.data,
      qt_meta_data_ButtonGrid,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ButtonGrid::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ButtonGrid::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ButtonGrid.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ButtonGrid::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void ButtonGrid::signalChangeStatusbar(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ButtonGrid::possibleKanji(const QList<Kanji> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ButtonGrid::clearButtonSelections()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
