// This file is generated by kconfig_compiler_kf5 from kanjibrowserconfig.kcfg.
// All changes you do to this file will be lost.

#include "kanjibrowserconfig.h"

#include <qglobal.h>
#include <QtCore/QFile>

class KanjiBrowserConfigSkeletonHelper
{
  public:
    KanjiBrowserConfigSkeletonHelper() : q(nullptr) {}
    ~KanjiBrowserConfigSkeletonHelper() { delete q; }
    KanjiBrowserConfigSkeleton *q;
};
Q_GLOBAL_STATIC(KanjiBrowserConfigSkeletonHelper, s_globalKanjiBrowserConfigSkeleton)
KanjiBrowserConfigSkeleton *KanjiBrowserConfigSkeleton::self()
{
  if (!s_globalKanjiBrowserConfigSkeleton()->q) {
    new KanjiBrowserConfigSkeleton;
    s_globalKanjiBrowserConfigSkeleton()->q->read();
  }

  return s_globalKanjiBrowserConfigSkeleton()->q;
}

KanjiBrowserConfigSkeleton::KanjiBrowserConfigSkeleton(  )
  : KConfigSkeleton( QStringLiteral( "kitenkanjibrowserrc" ) )
{
  Q_ASSERT(!s_globalKanjiBrowserConfigSkeleton()->q);
  s_globalKanjiBrowserConfigSkeleton()->q = this;
  setCurrentGroup( QStringLiteral( "Options" ) );


        QFont kanjiListFnt = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
        kanjiListFnt.setPointSize( 24 );
      
  KConfigSkeleton::ItemFont  *itemKanjiListFont;
  itemKanjiListFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "kanjiListFont" ), mKanjiListFont, kanjiListFnt );
  addItem( itemKanjiListFont, QStringLiteral( "kanjiListFont" ) );
  KConfigSkeleton::ItemDouble  *itemKanjiSize;
  itemKanjiSize = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "kanjiSize" ), mKanjiSize, 150 );
  addItem( itemKanjiSize, QStringLiteral( "kanjiSize" ) );

        QFont kanaFnt = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
        kanaFnt.setPointSize( 22 );
      
  KConfigSkeleton::ItemFont  *itemKanaFont;
  itemKanaFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "kanaFont" ), mKanaFont, kanaFnt );
  addItem( itemKanaFont, QStringLiteral( "kanaFont" ) );

        QFont labelFnt = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
        labelFnt.setPointSize( 22 );
        labelFnt.setWeight( QFont::Bold );
      
  KConfigSkeleton::ItemFont  *itemLabelFont;
  itemLabelFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "labelFont" ), mLabelFont, labelFnt );
  addItem( itemLabelFont, QStringLiteral( "labelFont" ) );
}

KanjiBrowserConfigSkeleton::~KanjiBrowserConfigSkeleton()
{
  s_globalKanjiBrowserConfigSkeleton()->q = nullptr;
}

