/****************************************************************************
** Meta object code from reading C++ file 'kiten.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.08.3/app/kiten.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kiten.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kiten_t {
    QByteArrayData data[36];
    char stringdata0[497];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kiten_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kiten_t qt_meta_stringdata_Kiten = {
    {
QT_MOC_LITERAL(0, 0, 5), // "Kiten"
QT_MOC_LITERAL(1, 6, 18), // "searchTextAndRaise"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 3), // "str"
QT_MOC_LITERAL(4, 30, 18), // "addExportListEntry"
QT_MOC_LITERAL(5, 49, 5), // "index"
QT_MOC_LITERAL(6, 55, 10), // "finishInit"
QT_MOC_LITERAL(7, 66, 16), // "focusResultsView"
QT_MOC_LITERAL(8, 83, 14), // "searchFromEdit"
QT_MOC_LITERAL(9, 98, 10), // "searchText"
QT_MOC_LITERAL(10, 109, 15), // "searchClipboard"
QT_MOC_LITERAL(11, 125, 16), // "searchAndDisplay"
QT_MOC_LITERAL(12, 142, 9), // "DictQuery"
QT_MOC_LITERAL(13, 152, 15), // "searchInResults"
QT_MOC_LITERAL(14, 168, 14), // "displayResults"
QT_MOC_LITERAL(15, 183, 10), // "EntryList*"
QT_MOC_LITERAL(16, 194, 13), // "radicalSearch"
QT_MOC_LITERAL(17, 208, 18), // "kanjiBrowserSearch"
QT_MOC_LITERAL(18, 227, 13), // "slotConfigure"
QT_MOC_LITERAL(19, 241, 17), // "slotConfigureHide"
QT_MOC_LITERAL(20, 259, 20), // "slotConfigureDestroy"
QT_MOC_LITERAL(21, 280, 17), // "configureToolBars"
QT_MOC_LITERAL(22, 298, 19), // "configureGlobalKeys"
QT_MOC_LITERAL(23, 318, 16), // "newToolBarConfig"
QT_MOC_LITERAL(24, 335, 19), // "updateConfiguration"
QT_MOC_LITERAL(25, 355, 16), // "loadDictionaries"
QT_MOC_LITERAL(26, 372, 14), // "loadDictConfig"
QT_MOC_LITERAL(27, 387, 5), // "print"
QT_MOC_LITERAL(28, 393, 4), // "back"
QT_MOC_LITERAL(29, 398, 7), // "forward"
QT_MOC_LITERAL(30, 406, 11), // "goInHistory"
QT_MOC_LITERAL(31, 418, 18), // "displayHistoryItem"
QT_MOC_LITERAL(32, 437, 10), // "addHistory"
QT_MOC_LITERAL(33, 448, 20), // "enableHistoryButtons"
QT_MOC_LITERAL(34, 469, 21), // "setCurrentScrollValue"
QT_MOC_LITERAL(35, 491, 5) // "value"

    },
    "Kiten\0searchTextAndRaise\0\0str\0"
    "addExportListEntry\0index\0finishInit\0"
    "focusResultsView\0searchFromEdit\0"
    "searchText\0searchClipboard\0searchAndDisplay\0"
    "DictQuery\0searchInResults\0displayResults\0"
    "EntryList*\0radicalSearch\0kanjiBrowserSearch\0"
    "slotConfigure\0slotConfigureHide\0"
    "slotConfigureDestroy\0configureToolBars\0"
    "configureGlobalKeys\0newToolBarConfig\0"
    "updateConfiguration\0loadDictionaries\0"
    "loadDictConfig\0print\0back\0forward\0"
    "goInHistory\0displayHistoryItem\0"
    "addHistory\0enableHistoryButtons\0"
    "setCurrentScrollValue\0value"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kiten[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  159,    2, 0x0a /* Public */,
       4,    1,  162,    2, 0x0a /* Public */,
       6,    0,  165,    2, 0x08 /* Private */,
       7,    0,  166,    2, 0x08 /* Private */,
       8,    0,  167,    2, 0x08 /* Private */,
       9,    1,  168,    2, 0x08 /* Private */,
      10,    0,  171,    2, 0x08 /* Private */,
      11,    1,  172,    2, 0x08 /* Private */,
      13,    0,  175,    2, 0x08 /* Private */,
      14,    1,  176,    2, 0x08 /* Private */,
      16,    0,  179,    2, 0x08 /* Private */,
      17,    0,  180,    2, 0x08 /* Private */,
      18,    0,  181,    2, 0x08 /* Private */,
      19,    0,  182,    2, 0x08 /* Private */,
      20,    0,  183,    2, 0x08 /* Private */,
      21,    0,  184,    2, 0x08 /* Private */,
      22,    0,  185,    2, 0x08 /* Private */,
      23,    0,  186,    2, 0x08 /* Private */,
      24,    0,  187,    2, 0x08 /* Private */,
      25,    0,  188,    2, 0x08 /* Private */,
      26,    1,  189,    2, 0x08 /* Private */,
      27,    0,  192,    2, 0x08 /* Private */,
      28,    0,  193,    2, 0x08 /* Private */,
      29,    0,  194,    2, 0x08 /* Private */,
      30,    1,  195,    2, 0x08 /* Private */,
      31,    0,  198,    2, 0x08 /* Private */,
      32,    1,  199,    2, 0x08 /* Private */,
      33,    0,  202,    2, 0x08 /* Private */,
      34,    1,  203,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   35,

       0        // eod
};

void Kiten::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Kiten *_t = static_cast<Kiten *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->searchTextAndRaise((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->addExportListEntry((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->finishInit(); break;
        case 3: _t->focusResultsView(); break;
        case 4: _t->searchFromEdit(); break;
        case 5: _t->searchText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->searchClipboard(); break;
        case 7: _t->searchAndDisplay((*reinterpret_cast< const DictQuery(*)>(_a[1]))); break;
        case 8: _t->searchInResults(); break;
        case 9: _t->displayResults((*reinterpret_cast< EntryList*(*)>(_a[1]))); break;
        case 10: _t->radicalSearch(); break;
        case 11: _t->kanjiBrowserSearch(); break;
        case 12: _t->slotConfigure(); break;
        case 13: _t->slotConfigureHide(); break;
        case 14: _t->slotConfigureDestroy(); break;
        case 15: _t->configureToolBars(); break;
        case 16: _t->configureGlobalKeys(); break;
        case 17: _t->newToolBarConfig(); break;
        case 18: _t->updateConfiguration(); break;
        case 19: _t->loadDictionaries(); break;
        case 20: _t->loadDictConfig((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->print(); break;
        case 22: _t->back(); break;
        case 23: _t->forward(); break;
        case 24: _t->goInHistory((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->displayHistoryItem(); break;
        case 26: _t->addHistory((*reinterpret_cast< EntryList*(*)>(_a[1]))); break;
        case 27: _t->enableHistoryButtons(); break;
        case 28: _t->setCurrentScrollValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kiten::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_Kiten.data,
      qt_meta_data_Kiten,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kiten::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kiten::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kiten.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Kiten::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
