/****************************************************************************
** Meta object code from reading C++ file 'configsortingpage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kiten-17.08.3/app/configsortingpage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configsortingpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ConfigSortingPage_t {
    QByteArrayData data[8];
    char stringdata0[104];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ConfigSortingPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ConfigSortingPage_t qt_meta_stringdata_ConfigSortingPage = {
    {
QT_MOC_LITERAL(0, 0, 17), // "ConfigSortingPage"
QT_MOC_LITERAL(1, 18, 13), // "widgetChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 10), // "hasChanged"
QT_MOC_LITERAL(4, 44, 9), // "isDefault"
QT_MOC_LITERAL(5, 54, 14), // "updateSettings"
QT_MOC_LITERAL(6, 69, 13), // "updateWidgets"
QT_MOC_LITERAL(7, 83, 20) // "updateWidgetsDefault"

    },
    "ConfigSortingPage\0widgetChanged\0\0"
    "hasChanged\0isDefault\0updateSettings\0"
    "updateWidgets\0updateWidgetsDefault"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ConfigSortingPage[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   45,    2, 0x0a /* Public */,
       4,    0,   46,    2, 0x0a /* Public */,
       5,    0,   47,    2, 0x0a /* Public */,
       6,    0,   48,    2, 0x0a /* Public */,
       7,    0,   49,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ConfigSortingPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ConfigSortingPage *_t = static_cast<ConfigSortingPage *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->widgetChanged(); break;
        case 1: { bool _r = _t->hasChanged();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->isDefault();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->updateSettings(); break;
        case 4: _t->updateWidgets(); break;
        case 5: _t->updateWidgetsDefault(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ConfigSortingPage::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ConfigSortingPage::widgetChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject ConfigSortingPage::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ConfigSortingPage.data,
      qt_meta_data_ConfigSortingPage,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ConfigSortingPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ConfigSortingPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ConfigSortingPage.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::configSorting"))
        return static_cast< Ui::configSorting*>(this);
    return QWidget::qt_metacast(_clname);
}

int ConfigSortingPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void ConfigSortingPage::widgetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
