#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'preferences.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREFERENCES_H
#define UI_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_preferences
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QFormLayout *formLayout;
    QLabel *_kanjiListFontLabel;
    KFontRequester *kcfg_kanjiListFont;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QFormLayout *formLayout_2;
    QLabel *_kanjiSizeLabel;
    QDoubleSpinBox *kcfg_kanjiSize;
    QFormLayout *formLayout_3;
    QLabel *_kanaFontLabel;
    KFontRequester *kcfg_kanaFont;
    QFormLayout *formLayout_4;
    QLabel *_labelFontLabel;
    KFontRequester *kcfg_labelFont;

    void setupUi(QWidget *preferences)
    {
        if (preferences->objectName().isEmpty())
            preferences->setObjectName(QStringLiteral("preferences"));
        preferences->resize(700, 300);
        verticalLayout = new QVBoxLayout(preferences);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        groupBox = new QGroupBox(preferences);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        formLayout = new QFormLayout();
        formLayout->setObjectName(QStringLiteral("formLayout"));
        formLayout->setLabelAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        _kanjiListFontLabel = new QLabel(groupBox);
        _kanjiListFontLabel->setObjectName(QStringLiteral("_kanjiListFontLabel"));
        _kanjiListFontLabel->setAlignment(Qt::AlignBottom|Qt::AlignLeading|Qt::AlignLeft);

        formLayout->setWidget(0, QFormLayout::LabelRole, _kanjiListFontLabel);

        kcfg_kanjiListFont = new KFontRequester(groupBox);
        kcfg_kanjiListFont->setObjectName(QStringLiteral("kcfg_kanjiListFont"));
        QFont font;
        font.setFamily(QStringLiteral("Sans Serif"));
        font.setPointSize(24);
        font.setBold(false);
        font.setItalic(false);
        font.setWeight(50);
        kcfg_kanjiListFont->setFont(font);

        formLayout->setWidget(0, QFormLayout::FieldRole, kcfg_kanjiListFont);


        verticalLayout_2->addLayout(formLayout);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(preferences);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        formLayout_2->setLabelAlignment(Qt::AlignCenter);
        formLayout_2->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        formLayout_2->setContentsMargins(0, -1, 0, -1);
        _kanjiSizeLabel = new QLabel(groupBox_2);
        _kanjiSizeLabel->setObjectName(QStringLiteral("_kanjiSizeLabel"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, _kanjiSizeLabel);

        kcfg_kanjiSize = new QDoubleSpinBox(groupBox_2);
        kcfg_kanjiSize->setObjectName(QStringLiteral("kcfg_kanjiSize"));
        kcfg_kanjiSize->setMaximum(999.99);
        kcfg_kanjiSize->setValue(150);

        formLayout_2->setWidget(0, QFormLayout::FieldRole, kcfg_kanjiSize);


        verticalLayout_3->addLayout(formLayout_2);

        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName(QStringLiteral("formLayout_3"));
        formLayout_3->setFormAlignment(Qt::AlignHCenter|Qt::AlignTop);
        _kanaFontLabel = new QLabel(groupBox_2);
        _kanaFontLabel->setObjectName(QStringLiteral("_kanaFontLabel"));

        formLayout_3->setWidget(0, QFormLayout::LabelRole, _kanaFontLabel);

        kcfg_kanaFont = new KFontRequester(groupBox_2);
        kcfg_kanaFont->setObjectName(QStringLiteral("kcfg_kanaFont"));
        QFont font1;
        font1.setFamily(QStringLiteral("Sans Serif"));
        font1.setPointSize(16);
        font1.setBold(false);
        font1.setItalic(false);
        font1.setWeight(50);
        kcfg_kanaFont->setFont(font1);

        formLayout_3->setWidget(0, QFormLayout::FieldRole, kcfg_kanaFont);


        verticalLayout_3->addLayout(formLayout_3);

        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName(QStringLiteral("formLayout_4"));
        formLayout_4->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        _labelFontLabel = new QLabel(groupBox_2);
        _labelFontLabel->setObjectName(QStringLiteral("_labelFontLabel"));

        formLayout_4->setWidget(0, QFormLayout::LabelRole, _labelFontLabel);

        kcfg_labelFont = new KFontRequester(groupBox_2);
        kcfg_labelFont->setObjectName(QStringLiteral("kcfg_labelFont"));
        QFont font2;
        font2.setFamily(QStringLiteral("Sans Serif"));
        font2.setPointSize(16);
        font2.setBold(true);
        font2.setItalic(false);
        font2.setWeight(75);
        kcfg_labelFont->setFont(font2);

        formLayout_4->setWidget(0, QFormLayout::FieldRole, kcfg_labelFont);


        verticalLayout_3->addLayout(formLayout_4);


        verticalLayout->addWidget(groupBox_2);


        retranslateUi(preferences);

        QMetaObject::connectSlotsByName(preferences);
    } // setupUi

    void retranslateUi(QWidget *preferences)
    {
        preferences->setWindowTitle(tr2i18n("Preferences", Q_NULLPTR));
        groupBox->setTitle(tr2i18n("Kanji List", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        _kanjiListFontLabel->setToolTip(tr2i18n("The font for the main kanji/kana entry in list view", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        _kanjiListFontLabel->setWhatsThis(tr2i18n("Use this to adjust the button font", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        _kanjiListFontLabel->setText(tr2i18n("Kanji font:", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        kcfg_kanjiListFont->setToolTip(QString());
#endif // QT_NO_TOOLTIP
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_kanjiListFont->setWhatsThis(QString());
#endif // QT_NO_WHATSTHIS
        kcfg_kanjiListFont->setSampleText(tr2i18n("\346\274\242\345\255\227", Q_NULLPTR));
        groupBox_2->setTitle(tr2i18n("Kanji Information", Q_NULLPTR));
        _kanjiSizeLabel->setText(tr2i18n("Kanji size:", Q_NULLPTR));
        _kanaFontLabel->setText(tr2i18n("Kana font:", Q_NULLPTR));
        kcfg_kanaFont->setSampleText(tr2i18n("\343\201\213\343\201\252", Q_NULLPTR));
        _labelFontLabel->setText(tr2i18n("Label font:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class preferences: public Ui_preferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREFERENCES_H

