// This file is generated by kconfig_compiler_kf5 from kiten.kcfg.
// All changes you do to this file will be lost.

#include "kitenconfig.h"

#include <qglobal.h>
#include <QtCore/QFile>

class KitenConfigSkeletonHelper
{
  public:
    KitenConfigSkeletonHelper() : q(nullptr) {}
    ~KitenConfigSkeletonHelper() { delete q; }
    KitenConfigSkeleton *q;
};
Q_GLOBAL_STATIC(KitenConfigSkeletonHelper, s_globalKitenConfigSkeleton)
KitenConfigSkeleton *KitenConfigSkeleton::self()
{
  if (!s_globalKitenConfigSkeleton()->q) {
    new KitenConfigSkeleton;
    s_globalKitenConfigSkeleton()->q->read();
  }

  return s_globalKitenConfigSkeleton()->q;
}

KitenConfigSkeleton::KitenConfigSkeleton(  )
  : KConfigSkeleton( QStringLiteral( "kitenrc" ) )
{
  Q_ASSERT(!s_globalKitenConfigSkeleton()->q);
  s_globalKitenConfigSkeleton()->q = this;
  setCurrentGroup( QStringLiteral( "dict_config_types" ) );

  QStringList defaultdictionary_list;
  defaultdictionary_list.append( QString::fromUtf8( "edict" ) );
  defaultdictionary_list.append( QString::fromUtf8( "kanjidic" ) );

  KConfigSkeleton::ItemStringList  *itemDictionary_list;
  itemDictionary_list = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "dictionary_list" ), mDictionary_list, defaultdictionary_list );
  addItem( itemDictionary_list, QStringLiteral( "dictionary_list" ) );

  setCurrentGroup( QStringLiteral( "dicts_edict" ) );

  KConfigSkeleton::ItemStringList  *itemEdict__NAMES;
  itemEdict__NAMES = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "__NAMES" ), mEdict__NAMES );
  addItem( itemEdict__NAMES, QStringLiteral( "edict__NAMES" ) );
  KConfigSkeleton::ItemBool  *itemEdict__useGlobal;
  itemEdict__useGlobal = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "__useGlobal" ), mEdict__useGlobal, true );
  addItem( itemEdict__useGlobal, QStringLiteral( "edict__useGlobal" ) );
  QStringList defaultedict__displayFields;
  defaultedict__displayFields.append( QString::fromUtf8( "Word/Kanji" ) );
  defaultedict__displayFields.append( QString::fromUtf8( "Reading" ) );
  defaultedict__displayFields.append( QString::fromUtf8( "Meaning" ) );

  KConfigSkeleton::ItemStringList  *itemEdict__displayFields;
  itemEdict__displayFields = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "__displayFields" ), mEdict__displayFields, defaultedict__displayFields );
  addItem( itemEdict__displayFields, QStringLiteral( "edict__displayFields" ) );

  setCurrentGroup( QStringLiteral( "dicts_kanjidic" ) );

  KConfigSkeleton::ItemStringList  *itemKanjidic__NAMES;
  itemKanjidic__NAMES = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "__NAMES" ), mKanjidic__NAMES );
  addItem( itemKanjidic__NAMES, QStringLiteral( "kanjidic__NAMES" ) );
  KConfigSkeleton::ItemBool  *itemKanjidic__useGlobal;
  itemKanjidic__useGlobal = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "__useGlobal" ), mKanjidic__useGlobal, true );
  addItem( itemKanjidic__useGlobal, QStringLiteral( "kanjidic__useGlobal" ) );
  QStringList defaultkanjidic__displayFields;
  defaultkanjidic__displayFields.append( QString::fromUtf8( "Word/Kanji" ) );
  defaultkanjidic__displayFields.append( QString::fromUtf8( "Reading" ) );
  defaultkanjidic__displayFields.append( QString::fromUtf8( "Meaning" ) );

  KConfigSkeleton::ItemStringList  *itemKanjidic__displayFields;
  itemKanjidic__displayFields = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "__displayFields" ), mKanjidic__displayFields, defaultkanjidic__displayFields );
  addItem( itemKanjidic__displayFields, QStringLiteral( "kanjidic__displayFields" ) );

  setCurrentGroup( QStringLiteral( "Searching Options" ) );

  KConfigSkeleton::ItemBool  *itemInitialSearch;
  itemInitialSearch = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "initialSearch" ), mInitialSearch, true );
  addItem( itemInitialSearch, QStringLiteral( "initialSearch" ) );
  KConfigSkeleton::ItemBool  *itemCaseSensitive;
  itemCaseSensitive = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "caseSensitive" ), mCaseSensitive, false );
  addItem( itemCaseSensitive, QStringLiteral( "caseSensitive" ) );

  setCurrentGroup( QStringLiteral( "Sorting" ) );

  KConfigSkeleton::ItemString  *itemDictionary_enable;
  itemDictionary_enable = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "dictionary_enable" ), mDictionary_enable, QStringLiteral( "true>" ) );
  addItem( itemDictionary_enable, QStringLiteral( "dictionary_enable" ) );
  QStringList defaultdictionary_sortlist;
  defaultdictionary_sortlist.append( QString::fromUtf8( "kanjidic" ) );
  defaultdictionary_sortlist.append( QString::fromUtf8( "edict" ) );

  KConfigSkeleton::ItemStringList  *itemDictionary_sortlist;
  itemDictionary_sortlist = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "dictionary_sortlist" ), mDictionary_sortlist, defaultdictionary_sortlist );
  addItem( itemDictionary_sortlist, QStringLiteral( "dictionary_sortlist" ) );
  QStringList defaultfield_sortlist;
  defaultfield_sortlist.append( QString::fromUtf8( "common" ) );

  KConfigSkeleton::ItemStringList  *itemField_sortlist;
  itemField_sortlist = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "field_sortlist" ), mField_sortlist, defaultfield_sortlist );
  addItem( itemField_sortlist, QStringLiteral( "field_sortlist" ) );

  setCurrentGroup( QStringLiteral( "Font" ) );

  KConfigSkeleton::ItemFont  *itemFont;
  itemFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "font" ), mFont );
  addItem( itemFont, QStringLiteral( "font" ) );
  KConfigSkeleton::ItemBool  *itemTextSameSize;
  itemTextSameSize = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "textSameSize" ), mTextSameSize, false );
  addItem( itemTextSameSize, QStringLiteral( "textSameSize" ) );
  KConfigSkeleton::ItemBool  *itemTextKanjiBig;
  itemTextKanjiBig = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "textKanjiBig" ), mTextKanjiBig, false );
  addItem( itemTextKanjiBig, QStringLiteral( "textKanjiBig" ) );
  KConfigSkeleton::ItemBool  *itemTextMainWordBig;
  itemTextMainWordBig = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "textMainWordBig" ), mTextMainWordBig, true );
  addItem( itemTextMainWordBig, QStringLiteral( "textMainWordBig" ) );

  setCurrentGroup( QStringLiteral( "app" ) );

  KConfigSkeleton::ItemInt  *itemFilter_rare;
  itemFilter_rare = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "filter_rare" ), mFilter_rare, 0 );
  addItem( itemFilter_rare, QStringLiteral( "filter_rare" ) );
  KConfigSkeleton::ItemInt  *itemSearch_precision;
  itemSearch_precision = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "search_precision" ), mSearch_precision, 3 );
  addItem( itemSearch_precision, QStringLiteral( "search_precision" ) );
  KConfigSkeleton::ItemInt  *itemSearch_limit_to_wordtype;
  itemSearch_limit_to_wordtype = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "search_limit_to_wordtype" ), mSearch_limit_to_wordtype, 0 );
  addItem( itemSearch_limit_to_wordtype, QStringLiteral( "search_limit_to_wordtype" ) );
  KConfigSkeleton::ItemBool  *itemAutosearch;
  itemAutosearch = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "autosearch" ), mAutosearch, false );
  addItem( itemAutosearch, QStringLiteral( "autosearch" ) );
}

KitenConfigSkeleton::~KitenConfigSkeleton()
{
  s_globalKitenConfigSkeleton()->q = nullptr;
}

